# Copyright 2006 HMC Architects, Ontario, CA, USA
#
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided the above
# copyright notice appear in all copies.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
#------------------------------------------------------------------------------------------------------------------------
# Name: 		PutOnCurrentLayer.rb 
#
# Version: 		v1.00
#
# Date: 		3/10/2006
#
# Author: 		Chris Grant @ HMC Architects
#
# Menu Item: 	Right Click Menu -> Put on Current Layer
#
# Description: 	Allows you to easily move entities and their nested elements (ie groups within components within groups) to the current layer
#
# Credit: 		Originally based on "layer.rb" - "change to current layer" by zdarc@163.com. 
#				However, other than the include statement this script is entirely custom. 
#				Without layer.rb as a starting place though, I may have never even bothered implementing this...
#------------------------------------------------------------------------------------------------------------------------
		
require 'sketchup.rb'

def putCurrentRecursion(ents,clayer)
	etype = ents.typename
	case etype
		when "Face"
			ents.layer=clayer if ents.layer!=clayer #if layer needs to be changed		
		when "Edge"
			ents.layer=clayer if ents.layer!=clayer #if layer needs to be changed				
		when "Group"				
			ents.layer=clayer if ents.layer!=clayer
			ents.entities.each do |ent|
				putCurrentRecursion(ent,clayer) #recursion happens here
			end
	 	when "ComponentInstance"
			ents.layer=clayer if ents.layer!=clayer
			begin
				ents.definition.entities.each do |ent|
					putCurrentRecursion(ent,clayer) #recursion happens here
				end
			rescue => err
				puts "EXCEPTION: #{err}"
			end
		else
			begin
				old = ents.layer.name.to_s
				new = clayer.name.to_s
				ents.layer=clayer if ents.layer!=clayer
				puts "Old: " + old + ", New: " + new
			rescue => err
				puts "EXCEPTION: #{err}"
			end
	end
end

def putCurrentLayer
	model = Sketchup.active_model
	layers = model.layers
	current = model.active_layer
	ents = model.active_entities
	sel=model.selection
	selindex=1
	
	model.start_operation "Transfert sur le calque actuel"
	sel.each do |selEnt|
		putCurrentRecursion(selEnt,current)
		Sketchup.set_status_text("Putting " + selindex.to_s + " of " + sel.count.to_s + " entities on current layer..." + "*"*selindex<<"") #set statusbar to fake progress bar
		selindex+=1 #increment progress index
	end
	model.commit_operation
	Sketchup.set_status_text("")
end

if( not file_loaded?("PutOnCurrentLayer.rb") )
  UI.add_context_menu_handler do |menu|
        menu.add_separator
 		menu.add_item("Put on Current Layer") { putCurrentLayer }
    end
end
file_loaded("PutOnCurrentLayer.rb")